@@ -121,7 +121,8 @@ class EsHelper:
                 "scroll": scroll,
                 "scroll_id": scroll_id})
             data_size = len(res["hits"]["hits"])
-            logging.info("扫描{}:{}条花费时间{}ms,".format(route_key, str(skip) + "-" + str(skip + data_size), res["took"]))
+            logging.info(
+                "扫描{}:{}条花费时间{}ms,".format(route_key, str(skip) + "-" + str(skip + data_size), res["took"]))
             scroll_id = res.get("_scroll_id")
             # end of scroll
             if scroll_id is None or not res["hits"]["hits"]:
@@ -148,6 +149,12 @@ class EsHelper:
         }, find_condition=params)
         return res
 
+    async def es_search(self, route_key, body):
+        path = f"/{route_key}/_search"
+        url = self.pool.format_url(path)
+        res = self.pool.format_es_post(url, body=body)
+        return res
+
     def sync_send_es_post(self, bool_must_list=None, param_list=None, route_key="", sort_list=None, size=10,
                           offset=0,
                           track_total_hits=False):
@@ -235,7 +242,8 @@ class EsHelper:
                 "scroll": scroll,
                 "scroll_id": scroll_id})
             data_size = len(res["hits"]["hits"])
-            logging.info("扫描{}:{}条花费时间{}ms,".format(route_key, str(skip) + "-" + str(skip + data_size), res["took"]))
+            logging.info(
+                "扫描{}:{}条花费时间{}ms,".format(route_key, str(skip) + "-" + str(skip + data_size), res["took"]))
             scroll_id = res.get("_scroll_id")
             # end of scroll
             if scroll_id is None or not res["hits"]["hits"]:
@@ -325,3 +333,66 @@ class EsHelper:
         url = self.pool.format_url(path)
         res = self.pool.format_es_post(url, body=data)
         return res
+
+    def sync_es_search(self, route_key, body):
+        path = f"/{route_key}/_search"
+        url = self.pool.format_url(path)
+        res = self.pool.format_es_post(url, body=body)
+        if "error" in res:
+            raise Exception(f"res={res}")
+        return res
+
+    def sync_es_search_format_hits(self, route_key, body):
+        res = self.sync_es_search(route_key, body)
+        hits = res.get("hits", {})
+        data_count = hits.get("total", {}).get("value", 0)
+        data_list = hits.get("hits", [])
+        result = {
+            "data_count": data_count,
+            "data_list": data_list
+        }
+        return result
+
+    def sync_es_search_format_aggregations(self, route_key, body):
+        res = self.sync_es_search(route_key, body)
+        hits = res.get("hits", {})
+        data_count = hits.get("total", {}).get("value", 0)
+        data_list = hits.get("hits", [])
+        aggregations = res.get("aggregations")
+        result = {
+            "data_count": data_count,
+            "data_list": data_list,
+            "aggregations": aggregations
+        }
+        return result
+
+    def sync_es_scan(self, route_key, body, scroll="5m"):
+        path = f"/{route_key}/_search?scroll={scroll}"
+        url = self.pool.format_url(path)
+        res = self.pool.format_es_post(url, body=body)
+        data_list = []
+        if "error" in res:
+            raise Exception(f"res={res}")
+        hits = res.get("hits", {}).get("hits", [])
+        for x in hits:
+            data_list.append(x)
+        scroll_id = res.get("_scroll_id")
+        scroll_path = f"/_search/scroll"
+        scroll_url = self.pool.format_url(scroll_path)
+        while scroll_id:
+            res = self.pool.format_es_post(scroll_url, body={'scroll': scroll, 'scroll_id': scroll_id})
+            if "error" in res:
+                raise Exception(f"res={res}")
+            hits = res.get("hits", {}).get("hits", [])
+            scroll_id = res.get("_scroll_id")
+            if hits:
+                for x in hits:
+                    data_list.append(x)
+            else:
+                break
+        data_count = len(data_list)
+        result = {
+            "data_count": data_count,
+            "data_list": data_list
+        }
+        return result
