@@ -3,15 +3,13 @@
 # email:yuyc@ishangqi.com
 # date:2021/11/26 3:56 下午
 # Copyright (C) 2021 The lesscode Team
-import logging
-import traceback
 from functools import reduce
 
+from nebula3.data.DataObject import Value, ValueWrapper, Relationship, PathWrapper, Node, Null
 from nebula3.data.ResultSet import ResultSet
-from tornado.options import options
-from nebula3.data.DataObject import Value, ValueWrapper, Relationship, PathWrapper
 from nebula3.mclient import MetaCache, HostAddr
 from nebula3.sclient.GraphStorageClient import GraphStorageClient
+from tornado.options import options
 
 
 class NebulaHelper:
@@ -165,6 +163,15 @@ def customized_cast_with_dict(val: ValueWrapper):
                 relationship.update({k: customized_cast_with_dict(v) for k, v in rel.properties().items()})
                 relationships.append(relationship)
             value = {"nodes": nodes, "relationships": relationships}
+        elif isinstance(value, Node):
+            nodes = []
+            for tag in value.tags():
+                point = {"_vid": customized_cast_with_dict(value.get_id()), "_tag": tag}
+                point.update({k: customized_cast_with_dict(v) for k, v in value.properties(tag).items()})
+                nodes.append(point)
+            value = {"nodes": nodes}
+        elif isinstance(value, Null):
+            value = None
         return value
     raise KeyError("No such key: {}".format(_type))
 
