@@ -4,6 +4,7 @@ import functools
 import inspect
 import json
 import logging
+import sys
 import traceback
 
 from lesscode.db.redis.redis_helper import RedisHelper
@@ -33,14 +34,13 @@ def deal_cache(func, ex, cache_key, *args, **params):
     if not cache_key:
         cache_key = format_insert_key(signature, func_name, args, params)
     value = query_cache(cache_key)
-    if value:
+    if value is not False:
         data = value
     else:
         start = datetime.datetime.now()
         logging.info("[组件：{}]数据开始计算！".format(func_name))
         copy_params = copy.deepcopy(params)
         data = func(*args, **copy_params)
-
         # 插入缓存表
         insert_cache(data, ex, cache_key)
         logging.info("[组件：{}]数据缓存已刷新！用时{}".format(func_name, datetime.datetime.now() - start))
@@ -48,7 +48,9 @@ def deal_cache(func, ex, cache_key, *args, **params):
     return data
 
 
-def query_cache(cache_key, conn_name=options.cache_conn):
+def query_cache(cache_key, conn_name=None):
+    if conn_name is None:
+        conn_name = options.cache_conn
     if options.cache_enable:
         data = RedisHelper(conn_name).sync_get(cache_key)
         if data:
@@ -61,11 +63,13 @@ def query_cache(cache_key, conn_name=options.cache_conn):
 
 
 def format_insert_key(signature, func_name, args, params):
-    _args = copy.deepcopy(args)
+    _args = []
     param_keys = list(signature.parameters.keys())
     if param_keys and args:
         if param_keys[0] == "self":
             _args = copy.deepcopy(args[1:])
+        else:
+            _args = copy.deepcopy(args)
     if isinstance(_args, tuple):
         _args = list(_args)
     for k in params:
@@ -76,9 +80,13 @@ def format_insert_key(signature, func_name, args, params):
     return str_insert_key
 
 
-def insert_cache(data, ex, cache_key, conn_name=options.cache_conn):
-    if options.cache_enable:
-        try:
-            RedisHelper(conn_name).sync_set(cache_key, JSONEncoder().encode(data), ex=ex)
-        except:
-            logging.error(traceback.format_exc())
+def insert_cache(data, ex, cache_key, conn_name=None):
+    # 大于512kb不缓存
+    if sys.getsizeof(data) <= 512 * 1024:
+        if conn_name is None:
+            conn_name = options.cache_conn
+        if options.cache_enable:
+            try:
+                RedisHelper(conn_name).sync_set(cache_key, JSONEncoder().encode(data), ex=ex)
+            except:
+                logging.error(traceback.format_exc())
