@@ -44,7 +44,7 @@ def format_es_param_result(r, param_list, is_need_decrypt_oralce, is_need_es_sco
                 else:
                     pass
             if result_dict.get(key) is None:
-                if value:
+                if value is not None:
                     result_dict[key] = value
     else:
         result_dict = r["_source"]
