@@ -306,7 +306,7 @@ class BaseHandler(RequestHandler):
                 for key in user_info:
                     value = user_info.get(key)
                     if value and isinstance(value, str):
-                        value = unquote(value)
+                        user_info[key] = unquote(value)
                     if key == "roleIds" and value and isinstance(value, str):
                         user_info[key] = json.loads(value)
                     setattr(user, key, user_info[key])
